@@ -15,6 +15,9 @@ pub enum Value {
     #[tag("Number")]
     Number(Number),
 
+    #[tag("Integer")]
+    Integer(Integer),
+
     #[tag("Percentage")]
     Percentage(Percentage),
 
@@ -45,8 +48,8 @@ pub enum Value {
     #[tag("Url")]
     Url(Url),
 
-    #[tag("Urange")]
-    Urange(Urange),
+    #[tag("UnicodeRange")]
+    UnicodeRange(UnicodeRange),
 
     #[tag("ComplexSelector")]
     ComplexSelector(ComplexSelector),
@@ -206,6 +209,13 @@ pub struct Percentage {
     pub value: Number,
 }
 
+#[ast_node("Integer")]
+pub struct Integer {
+    pub span: Span,
+    pub value: i64,
+    pub raw: JsWord,
+}
+
 #[ast_node("Number")]
 pub struct Number {
     pub span: Span,
@@ -265,10 +275,12 @@ pub enum UrlModifier {
     Function(Function),
 }
 
-#[ast_node("Urange")]
-pub struct Urange {
+#[ast_node("UnicodeRange")]
+pub struct UnicodeRange {
     pub span: Span,
-    pub value: JsWord,
+    pub prefix: char,
+    pub start: JsWord,
+    pub end: Option<JsWord>,
 }
 
 #[ast_node("CalcSum")]
